@@ -2,8 +2,6 @@ from traits.api import *
 from traitsui.api import *#View, Item, ButtonEditor, Group, HSplit,
 from traitsui.menu import *
 
-import numpy as npy
-import os
 import pylab as plb
 import skrf as rf
 
@@ -49,7 +47,8 @@ class PlotTool(HasTraits):
 
     def _apply_title_fired(self):
         plb.title(self.title)
-        plb.draw();plb.show()
+        plb.draw()
+        plb.show()
 
     view = View(
         Group(
