@@ -2,10 +2,8 @@ from traits.api import *
 from traitsui.api import *#View, Item, ButtonEditor, Group, HSplit,
 from traitsui.menu import *
 
-import pylab as plb
 import skrf as rf
 import os
-from plotTool import PlotTool
 
 class Network2Spreadsheet(HasTraits):
     input_dir = Directory('')
@@ -25,7 +23,7 @@ class Network2Spreadsheet(HasTraits):
     def _get_ntwk_dict(self):
         try:
             return rf.ran(self.input_dir)
-        except(OSError):
+        except OSError:
             return {}
 
     def _get_available_ntwk_list(self):
@@ -34,13 +32,13 @@ class Network2Spreadsheet(HasTraits):
     def _get_active_ntwk(self):
         try:
             return self.ntwk_dict[self.active_ntwk_name]
-        except:
+        except KeyError:
             pass
 
     def _get_ports(self):
         try:
             return ['All']+range(self.active_ntwk.nports)
-        except:
+        except TypeError:
             return []
 
     def _export_network_fired(self):
