@@ -10,9 +10,8 @@ author = 'scikit-rf team'
 
 # -- General configuration ---------------------------------------------------
 
-import sys, os
-import sphinx_rtd_theme
-import nbsphinx
+import sys
+import os
 import warnings
 warnings.filterwarnings('ignore')
 
@@ -21,7 +20,7 @@ warnings.filterwarnings('ignore')
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 sys.path.insert(0, os.path.abspath('../../'))
 
-import skrf as rf 
+import skrf as rf
 rf.setup_pylab()
 
 # Add any Sphinx extension module names here, as strings. They can be
@@ -34,11 +33,13 @@ sys.path.insert(0, os.path.abspath('../sphinxext'))
 
 extensions = [
     'sphinx.ext.autodoc',
+    'sphinx.ext.autosectionlabel',
     'sphinx.ext.autosummary',
     'sphinx.ext.napoleon',
     'sphinx.ext.mathjax',
     'sphinx.ext.viewcode',
     'sphinx.ext.intersphinx',
+    'sphinx_rtd_theme',
     'nbsphinx',
     #'inheritance_diagram',
     'IPython.sphinxext.ipython_directive',
@@ -95,11 +96,10 @@ pygments_style = 'sphinx'
 # further.  For a list of options available for each theme, see the
 # documentation.
 
-# Add any paths that contain custom themes here, relative to this directory.
-
 html_theme = "sphinx_rtd_theme"
 
-html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
+# Add any paths that contain custom themes here, relative to this directory.
+# html_theme_path = []
 
 # The name for this set of Sphinx documents.  If None, it defaults to
 # "<project> v<release> documentation".
@@ -179,8 +179,20 @@ man_pages = [
 
 # Example configuration for intersphinx: refer to the Python standard library.
 intersphinx_mapping = {
-    'python': ('https://docs.python.org/3/objects.inv', None),
+    'python': ('https://docs.python.org/3', None),
     'numpy': ('https://numpy.org/doc/stable', None),
     'pd': ('https://pandas.pydata.org/docs', None),
     'scipy': ('https://docs.scipy.org/doc/scipy/', None),
 }
+
+def process_signature(app, what, name, obj, options, signature, return_annotation):
+
+    func_name = name.split(".")[-1]
+    if func_name.startswith("plot_") and func_name[5:] in rf.Network._generated_functions().keys():
+        signature = signature.split(",")[2:]
+        return "(" + ", ".join(signature), return_annotation
+
+    return signature, return_annotation
+
+def setup(app):
+    app.connect("autodoc-process-signature", process_signature)
\ No newline at end of file
