@@ -1,9 +1,9 @@
 """
 skrf is an object-oriented approach to microwave engineering,
-implemented in Python. 
+implemented in Python.
 """
 
-__version__ = '0.25.0'
+__version__ = '0.30.0'
 ## Import all  module names for coherent reference of name-space
 #import io
 
@@ -34,9 +34,9 @@ from .util import *
 from .circuit import *
 from .mathFunctions import *
 from .tlineFunctions import *
-from .io import * 
-from .constants import * 
-from .taper import * 
+from .io import *
+from .constants import *
+from .taper import *
 from .instances import *
 from .vectorFitting import *
 from .qfactor import *
@@ -45,17 +45,18 @@ from .qfactor import *
 try:
     import vi
     from vi import *
-except(ImportError):
+except ImportError:
     pass
 
-# try to import data but if it fails whatever. it fails if some pickles 
+# try to import data but if it fails whatever. it fails if some pickles
 # dont unpickle. but its not important
 try:
     from . import data
-except:
-    pass 
-
+except Exception:
+    pass
 
+def __getattr__(name: str):
+    return getattr(instances._instances, name)
 
 ## built-in imports
 from copy import deepcopy as copy
@@ -72,7 +73,7 @@ saf = None
 stylely = None
 
 
-def setup_pylab():
+def setup_pylab() -> bool:
     try:
         import matplotlib
     except ImportError:
@@ -80,7 +81,6 @@ def setup_pylab():
         return False
 
     from . import plotting
-    plotting.setup_matplotlib_plotting()
 
     global saf, stylely
     saf = plotting.save_all_figs
@@ -99,4 +99,4 @@ def setup_plotting():
     # elif some different plotting environment
         # set that up
 
-setup_plotting()
+plotting_available = setup_plotting()
