@@ -82,9 +82,10 @@ Graph representation
    Circuit.edge_labels
 
 """
-from . network import Network, a2s, s2s
+from . network import Network, s2s
 from . media import media
 from . constants import INF, NumberLike, S_DEF_DEFAULT
+from . util import subplots
 
 import numpy as np
 
@@ -92,7 +93,6 @@ from itertools import chain, product
 
 from typing import List, TYPE_CHECKING, Tuple
 
-
 if TYPE_CHECKING:
     from .frequency import Frequency
 
@@ -113,7 +113,25 @@ class Circuit:
     .. [#] P. Hallbjörner, Microw. Opt. Technol. Lett. 38, 99 (2003).
 
     """
-    def __init__(self, connections: List[List[Tuple]]) -> None:
+    @staticmethod
+    def _get_nx():
+        """Returns networkx module if available.
+
+        Raises:
+        -------
+            ImportError: If networkx module is not installed
+
+        Returns:
+        --------
+            networkx module
+        """
+        try:
+            import networkx as nx
+            return nx
+        except ImportError as err:
+            raise ImportError('networkx package as not been installed and is required.') from err
+
+    def __init__(self, connections: List[List[Tuple]], name: str = None,) -> None:
         """
         Circuit constructor. Creates a circuit made of a set of N-ports networks.
 
@@ -124,6 +142,8 @@ class Circuit:
             Each connection is a described by a list of tuple.
             Each tuple contains (network, network_port_nb).
             Port number indexing starts from zero.
+        name : string, optional
+            Name assigned to the circuit (Network). Default is None.
 
 
         Examples
@@ -170,6 +190,7 @@ class Circuit:
 
         """
         self.connections = connections
+        self.name = name
 
         # check if all networks have a name
         for cnx in self.connections:
@@ -187,12 +208,12 @@ class Circuit:
                 raise AttributeError('All Networks must have same frequencies')
         # All frequencies are the same, Circuit frequency can be any of the ntw
         self.frequency = ntws[0].frequency
-        
+
         # Check that a (ntwk, port) combination appears only once in the connexion map
         nodes = [(ntwk.name, port) for (con_idx, (ntwk, port)) in [con for con in self.connections_list]]
         if len(nodes) > len(set(nodes)):
             raise AttributeError('A (network, port) node appears twice in the connection description.')
-        
+
 
     def _is_named(self, ntw):
         """
@@ -278,8 +299,7 @@ class Circuit:
         A[:, 0, 1] = Z
         A[:, 1, 0] = 0
         A[:, 1, 1] = 1
-        ntw = Network(frequency=frequency, z0=z0, name=name)
-        ntw.s = a2s(A)
+        ntw = Network(a=A, frequency=frequency, z0=z0, name=name)
         return ntw
 
     @classmethod
@@ -322,8 +342,7 @@ class Circuit:
         A[:, 0, 1] = 0
         A[:, 1, 0] = Y
         A[:, 1, 1] = 1
-        ntw = Network(frequency=frequency, z0=z0, name=name)
-        ntw.s = a2s(A)
+        ntw = Network(a=A, frequency=frequency, z0=z0, name=name)
         return ntw
 
     @classmethod
@@ -512,11 +531,8 @@ class Circuit:
         ----------
         .. [#] https://networkx.github.io/
         """
-        try:
-            import networkx as nx
-        except ImportError as e:
-            raise ImportError('networkx package as not been installed and is required. ')
 
+        nx = self._get_nx()
         G = nx.Graph()
         # Adding network nodes
         G.add_nodes_from([it for it in self.networks_dict(self.connections)])
@@ -537,15 +553,9 @@ class Circuit:
 
         Check if every pair of vertices in the graph is connected.
         """
-        # Get the circuit graph. Will raise an error if the networkx package
-        # is not installed.
-        G = self.G
 
-        try:
-            import networkx as nx
-            return nx.algorithms.components.is_connected(G)
-        except ImportError as e:
-            raise ImportError('networkx package as not been installed and is required. ')
+        nx = self._get_nx()
+        return nx.algorithms.components.is_connected(self.G)
 
 
     @property
@@ -748,7 +758,7 @@ class Circuit:
         for Xk in Xks:
             Xf[:, off[0]:off[0] + Xk.shape[1], off[1]:off[1]+Xk.shape[2]] = Xk
             off += Xk.shape[1:]
-        
+
         return Xf
 
     @property
@@ -801,11 +811,7 @@ class Circuit:
         S : :class:`numpy.ndarray`
             global scattering parameters of the circuit.
         """
-        # transpose is necessary to get expected result
-        #return np.transpose(self.X @ np.linalg.inv(np.identity(self.dim) - self.C @ self.X), axes=(0,2,1))
-        # does not use the @ operator for backward Python version compatibility
-        return np.transpose(np.matmul(self.X, np.linalg.inv(np.identity(self.dim) - np.matmul(self.C, self.X))), axes=(0,2,1))
-
+        return self.X @ np.linalg.inv(np.identity(self.dim) - self.C @ self.X)
 
     @property
     def port_indexes(self) -> list:
@@ -872,7 +878,7 @@ class Circuit:
             Shape `f x nb_ports x nb_ports`
         """
         port_indexes = self.port_indexes
-        a, b = np.meshgrid(port_indexes, port_indexes)
+        a, b = np.meshgrid(port_indexes, port_indexes, indexing='ij')
         S_ext = self.s[:, a, b]
         S_ext = s2s(S_ext, self.port_z0, S_DEF_DEFAULT, 'traveling')
         return S_ext  # shape (nb_frequency, nb_ports, nb_ports)
@@ -891,6 +897,7 @@ class Circuit:
         ntw.frequency = self.frequency
         ntw.z0 = self.port_z0
         ntw.s = self.s_external
+        ntw.name = self.name
         return ntw
 
 
@@ -1149,8 +1156,7 @@ class Circuit:
         phase excitation at "external" ports using `_a(power, phase)` method.
 
         """
-        # return self.s @ a_internal
-        return np.matmul(self.s, a_internal)
+        return self.s @ a_internal
 
     def currents(self, power: NumberLike, phase: NumberLike) -> np.ndarray:
         """
@@ -1290,3 +1296,115 @@ class Circuit:
         for port_idx in self.port_indexes:
             Vs.append((a[port_idx] + b[:,port_idx])*np.sqrt(z0s[:,port_idx]))
         return np.array(Vs).T
+
+    def plot_graph(self, **kwargs):
+        """
+        Plot the graph of the circuit using networkx drawing capabilities.
+
+        Customisation options with default values:
+        ::
+            'network_shape': 's'
+            'network_color': 'gray'
+            'network_size', 300
+            'network_fontsize': 7
+            'inter_shape': 'o'
+            'inter_color': 'lightblue'
+            'inter_size', 300
+            'port_shape': '>'
+            'port_color': 'red'
+            'port_size', 300
+            'port_fontsize': 7
+            'edges_fontsize': 5
+            'network_labels': False
+            'edge_labels': False
+            'inter_labels': False
+            'port_labels': False
+            'label_shift_x': 0
+            'label_shift_y': 0
+
+        """
+
+        nx = self._get_nx()
+        G = self.G
+
+        # default values
+        network_labels = kwargs.pop('network_labels', False)
+        network_shape = kwargs.pop('network_shape', 's')
+        network_color = kwargs.pop('network_color', 'gray')
+        network_fontsize = kwargs.pop('network_fontsize', 7)
+        network_size = kwargs.pop('network_size', 300)
+        inter_labels = kwargs.pop('inter_labels', False)
+        inter_shape = kwargs.pop('inter_shape', 'o')
+        inter_color = kwargs.pop('inter_color', 'lightblue')
+        inter_size = kwargs.pop('inter_size', 300)
+        port_labels = kwargs.pop('port_labels', False)
+        port_shape = kwargs.pop('port_shape', '>')
+        port_color = kwargs.pop('port_color', 'red')
+        port_size = kwargs.pop('port_size', 300)
+        port_fontsize = kwargs.pop('port_fontsize', 7)
+        edge_labels = kwargs.pop('edge_labels', False)
+        edge_fontsize = kwargs.pop('edge_fontsize', 5)
+        label_shift_x = kwargs.pop('label_shift_x', 0)
+        label_shift_y = kwargs.pop('label_shift_y', 0)
+
+
+        # sort between network nodes and port nodes
+        all_ntw_names = [ntw.name for ntw in self.networks_list()]
+        port_names = [ntw_name for ntw_name in all_ntw_names if 'port' in ntw_name]
+        ntw_names = [ntw_name for ntw_name in all_ntw_names if 'port' not in ntw_name]
+        # generate connecting nodes names
+        int_names = ['X'+str(k) for k in range(self.connections_nb)]
+
+        fig, ax = subplots(figsize=(10,8))
+
+        pos = nx.spring_layout(G)
+
+        # draw Networks
+        nx.draw_networkx_nodes(G, pos, port_names, ax=ax,
+                            node_size=port_size,
+                            node_color=port_color, node_shape=port_shape)
+        nx.draw_networkx_nodes(G, pos, ntw_names, ax=ax,
+                            node_size=network_size,
+                            node_color=network_color, node_shape=network_shape)
+        # draw intersections
+        nx.draw_networkx_nodes(G, pos, int_names, ax=ax,
+                            node_size=inter_size,
+                            node_color=inter_color, node_shape=inter_shape)
+        # labels shifts
+        pos_labels = {}
+        for node, coords in pos.items():
+            pos_labels[node] = (coords[0] + label_shift_x,
+                                coords[1] + label_shift_y)
+
+        # network labels
+        if network_labels:
+            network_labels = {lab:lab for lab in ntw_names}
+
+            nx.draw_networkx_labels(G, pos_labels, labels=network_labels,
+                                    font_size=network_fontsize, ax=ax)
+
+        # intersection labels
+        if inter_labels:
+            inter_labels = {'X'+str(k):'X'+str(k) for k in range(self.connections_nb)}
+
+            nx.draw_networkx_labels(G, pos_labels, labels=inter_labels,
+                                    font_size=network_fontsize, ax=ax)
+
+        # port labels
+        if port_labels:
+            port_labels = {lab:lab for lab in port_names}
+
+            nx.draw_networkx_labels(G, pos_labels, labels=port_labels,
+                                    font_size=port_fontsize, ax=ax)
+
+        # draw edges
+        nx.draw_networkx_edges(G, pos, ax=ax)
+        if edge_labels:
+            edge_labels = self.edge_labels
+            nx.draw_networkx_edge_labels(G, pos,
+                                        edge_labels=edge_labels, label_pos=0.5,
+                                        font_size=edge_fontsize, ax=ax)
+        # remove x and y axis and labels
+        ax.axis('off')
+        fig.tight_layout()
+
