@@ -62,6 +62,8 @@ JSON
 
 
 """
+from typing import List, Tuple, Optional
+
 import glob
 import inspect
 import json
@@ -70,8 +72,9 @@ import pickle
 from pickle import UnpicklingError
 import sys
 import warnings
-
 import numpy as npy
+from pandas import DataFrame, Series, ExcelWriter
+from io import StringIO
 
 from ..util import get_extn, get_fid
 from ..network import Network
@@ -80,13 +83,7 @@ from ..media import Media
 from ..networkSet import NetworkSet
 from ..calibration.calibration import Calibration
 
-from copy import copy
-dir_ = copy(dir)
-
-# delayed import: from pandas import DataFrame, Series for ntwk_2_spreadsheet
-
 # file extension conventions for skrf objects.
-global OBJ_EXTN
 OBJ_EXTN = [
     [Frequency, 'freq'],
     [Network, 'ntwk'],
@@ -117,7 +114,7 @@ def read(file, *args, **kwargs):
 
         * a file-object, it is left open
 
-        * a filename, then a file-object is opened and closed. 
+        * a filename, then a file-object is opened and closed.
 
         * a file-object and reading fails, then the position is reset back to 0 using seek if possible.
 
@@ -249,7 +246,8 @@ def write(file, obj, overwrite = True):
         pickle.dump(obj, fid, protocol=2)
         fid.close()
 
-def read_all(dir: str ='.', sort = True, contains = None, f_unit = None, obj_type=None, files: list=None, recursive=False) -> dict:
+def read_all(dir: str ='.', sort = True, contains = None, f_unit = None, 
+        obj_type=None, files: list=None, recursive=False) -> dict:
     """
     Read all skrf objects in a directory.
 
@@ -320,7 +318,7 @@ def read_all(dir: str ='.', sort = True, contains = None, f_unit = None, obj_typ
             filelist.append(filename)
     else:
         filelist.extend(files)
-         
+
     if sort is True:
         filelist.sort()
 
@@ -332,20 +330,20 @@ def read_all(dir: str ='.', sort = True, contains = None, f_unit = None, obj_typ
         try:
             out[keyname] = read(fullname)
             continue
-        except:
+        except Exception:
             pass
 
         try:
             out[keyname] = Network(fullname)
             continue
-        except:
+        except Exception:
             pass
 
     if f_unit is not None:
         for keyname in out:
             try:
                 out[keyname].frequency.unit = f_unit
-            except:
+            except Exception:
                 pass
 
     if obj_type is not None:
@@ -416,7 +414,7 @@ def write_all(dict_objs, dir='.', *args, **kwargs):
     """
     if not os.path.exists('.'):
         raise OSError('No such directory: %s'%dir)
-         
+
 
 
     for k in dict_objs:
@@ -501,7 +499,7 @@ def load_all_touchstones(dir = '.', contains=None, f_unit=None):
 
     Notes
     -------
-    
+
 
     Parameters
     -----------
@@ -537,8 +535,9 @@ def load_all_touchstones(dir = '.', contains=None, f_unit=None):
         try:
             if extn[1]== 's' and extn[-1]=='p':
                 ntwkDict[keyname]=(Network(dir +'/'+f))
-                if f_unit is not None: ntwkDict[keyname].frequency.unit=f_unit
-        except:
+                if f_unit is not None:
+                    ntwkDict[keyname].frequency.unit=f_unit
+        except Exception:
             pass
     return ntwkDict
 
@@ -620,9 +619,9 @@ def statistical_2_touchstone(file_name, new_file_name=None,\
             touchstone header written to first beginning of file
 
     """
-    if new_file_name is None:
+    remove_tmp_file = new_file_name is None
+    if remove_tmp_file:
         new_file_name = 'tmp-'+file_name
-        remove_tmp_file = True
 
     # This breaks compatibility with python 2.6 and older
     with open(file_name) as old_file, open(new_file_name, 'w') as new_file:
@@ -630,11 +629,11 @@ def statistical_2_touchstone(file_name, new_file_name=None,\
         for line in old_file:
             new_file.write(line)
 
-    if remove_tmp_file is True:
+    if remove_tmp_file:
         os.rename(new_file_name,file_name)
 
-def network_2_spreadsheet(ntwk, file_name =None, file_type= 'excel', form='db',
-    *args, **kwargs):
+def network_2_spreadsheet(ntwk: Network, file_name: str = None, 
+        file_type: str = 'excel', form: str ='db', *args, **kwargs):
     r"""
     Write a Network object to a spreadsheet, for your boss.
 
@@ -671,7 +670,6 @@ def network_2_spreadsheet(ntwk, file_name =None, file_type= 'excel', form='db',
     --------
     networkset_2_spreadsheet : writes a spreadsheet for many networks
     """
-    from pandas import DataFrame, Series # delayed because its not a requirement
     file_extns = {'csv':'csv','excel':'xls','html':'html'}
 
     form = form.lower()
@@ -690,7 +688,7 @@ def network_2_spreadsheet(ntwk, file_name =None, file_type= 'excel', form='db',
         file_name = ntwk.name + '.'+file_extns[file_type]
 
     d = {}
-    index =ntwk.frequency.f_scaled
+    index =ntwk.frequency.f
 
     if form =='db':
         for m,n in ntwk.port_tuples:
@@ -715,7 +713,8 @@ def network_2_spreadsheet(ntwk, file_name =None, file_type= 'excel', form='db',
     df.__getattribute__('to_%s'%file_type)(file_name,
         index_label='Freq(%s)'%ntwk.frequency.unit, *args, **kwargs)
 
-def network_2_dataframe(ntwk, attrs=['s_db'], ports = None):
+def network_2_dataframe(ntwk: Network, attrs: List[str] =['s_db'], 
+        ports: List[Tuple[int, int]] = None, port_sep: Optional[str] = None):
     """
     Convert one or more attributes of a network to a pandas DataFrame.
 
@@ -727,23 +726,29 @@ def network_2_dataframe(ntwk, attrs=['s_db'], ports = None):
         like ['s_db','s_deg']
     ports : list of tuples
         list of port pairs to write. defaults to ntwk.port_tuples
-        (like [[0,0]])
+        (like [(0,0)])
+    port_sep : string
+        defaults to None, which means a empty string "" is used for 
+        networks with lower than 10 ports. (s_db 11, s_db 21)
+        For more than ten ports a "_" is used to avoid ambiguity.
+        (s_db 1_1, s_db 2_1)    
 
     Returns
     -------
     df : pandas DataFrame Object
     """
-    from pandas import DataFrame, Series # delayed because its not a requirement
-
     if ports is None:
         ports = ntwk.port_tuples
 
+    if port_sep is None:
+        port_sep = "_" if ntwk.nports > 10 else ""
+
     d = {}
     for attr in attrs:
-        attr_array = ntwk.__getattribute__(attr)
+        attr_array = getattr(ntwk, attr)
         for m, n in ports:
-            d[f'{attr} {m+1}{n+1}'] = attr_array[:, m, n]
-    return DataFrame(d, index=ntwk.frequency.f_scaled)
+            d[f'{attr} {m+1}{port_sep}{n+1}'] = attr_array[:, m, n]
+    return DataFrame(d, index=ntwk.frequency.f)
 
 def networkset_2_spreadsheet(ntwkset: 'NetworkSet', file_name: str = None, file_type: str = 'excel',
     *args, **kwargs):
@@ -784,7 +789,6 @@ def networkset_2_spreadsheet(ntwkset: 'NetworkSet', file_name: str = None, file_
     --------
     networkset_2_spreadsheet : writes a spreadsheet for many networks
     """
-    from pandas import DataFrame, Series, ExcelWriter # delayed because its not a requirement
     if ntwkset.name is None and file_name is None:
         raise(ValueError('Either ntwkset must have name or give a file_name'))
     if file_name is None:
@@ -800,7 +804,6 @@ def networkset_2_spreadsheet(ntwkset: 'NetworkSet', file_name: str = None, file_
         [network_2_spreadsheet(k,*args, **kwargs) for k in ntwkset]
 
 
-from io import StringIO
 StringBuffer = StringIO
 
 
