@@ -4,10 +4,13 @@ of all general circuit components
 
 """
 import unittest
+import numpy as np
 from scipy.constants import *
 
 import skrf as rf
-from skrf.media import Freespace, CPW, RectangularWaveguide, DistributedCircuit
+from skrf.media import Freespace, CircularWaveguide, RectangularWaveguide
+from skrf.media import Media, Coaxial, DistributedCircuit
+from skrf.media import CPW, MLine
 
 
 class MediaTestCase():
@@ -15,8 +18,8 @@ class MediaTestCase():
     def test_gamma(self):
         self.media.gamma
 
-    def test_Z0_value(self):
-        self.media.Z0
+    def test_z0_value(self):
+        self.media.z0
 
     def test_match(self):
         self.media.match()
@@ -33,10 +36,14 @@ class MediaTestCase():
     def test_capacitor(self):
         self.media.capacitor(1)
 
+    def test_capacitor_q(self):
+        self.media.capacitor_q(1, 2, 3)
 
     def test_inductor(self):
         self.media.inductor(1)
 
+    def test_inductor_q(self):
+        self.media.capacitor_q(1, 2, 3)
 
     def test_impedance_mismatch(self):
         self.media.impedance_mismatch(1, 2)
@@ -76,21 +83,55 @@ class MediaTestCase():
 
     def test_shunt_inductor(self):
         self.media.shunt_inductor(1)
+    
+    def test_Z0_deprecation_warning(self):
+        with self.assertWarns(DeprecationWarning) as context:
+            self.media.Z0
+    
+    def test_embed_deprecation_warning(self):
+        with self.assertWarns(DeprecationWarning) as context:
+            self.media.line(1, unit = 'deg', embed = True)
 
+class Z0InitDeprecationTestCase(unittest.TestCase):
+    def setUp(self):
+        self.frequency = rf.Frequency(1,2,2,'GHz')
 
+    def testZ0InitDeprecation(self):
+        # 1-conductor waveguide media
+        with self.assertWarns(DeprecationWarning) as context:
+            cw = CircularWaveguide(self.frequency, z0 = 50)
+            self.assertTrue(np.all(cw.z0 == 50))
+        with self.assertWarns(DeprecationWarning) as context:
+            rw = RectangularWaveguide(self.frequency, z0 = 50)
+            self.assertTrue(np.all(rw.z0 == 50))
+        # 2-conductor other media
+        with self.assertWarns(DeprecationWarning) as context:
+            coax = Coaxial(self.frequency, z0 = 50)
+            self.assertTrue(np.all(coax.z0 == 50))
+        with self.assertWarns(DeprecationWarning) as context:
+            cpw = CPW(self.frequency, z0 = 50)
+            self.assertTrue(np.all(cpw.z0 == 50))
+        with self.assertWarns(DeprecationWarning) as context:
+            air = Freespace(self.frequency, z0 = 50)
+            self.assertTrue(np.all(air.z0 == 50))
+        with self.assertWarns(DeprecationWarning) as context:
+            mlin = MLine(self.frequency, z0 = 50)
+            self.assertTrue(np.all(mlin.z0 == 50))
+    
+    
 class FreespaceTestCase(MediaTestCase, unittest.TestCase):
     def setUp(self):
-        self.frequency = rf.Frequency(75,110,101,'ghz')
+        self.frequency = rf.Frequency(75,110,101,'GHz')
         self.media = Freespace(self.frequency)
 
-    def test_Z0_value(self):
+    def test_z0_value(self):
         self.assertEqual(round(\
-            self.media.Z0[0].real), 377)
+            self.media.z0[0].real), 377)
 
 
 class CPWTestCase(MediaTestCase, unittest.TestCase):
     def setUp(self):
-        self.frequency = rf.Frequency(75,110,101,'ghz')
+        self.frequency = rf.Frequency(75,110,101,'GHz')
         self.media = CPW(\
             frequency=self.frequency,
             w=10e-6,
@@ -102,7 +143,7 @@ class CPWTestCase(MediaTestCase, unittest.TestCase):
 
 class RectangularWaveguideTestCase(MediaTestCase, unittest.TestCase):
     def setUp(self):
-        self.frequency = rf.Frequency(75,110,101,'ghz')
+        self.frequency = rf.Frequency(75,110,101,'GHz')
         self.media = RectangularWaveguide(\
             frequency=self.frequency,
             a=100*mil,
@@ -111,7 +152,7 @@ class RectangularWaveguideTestCase(MediaTestCase, unittest.TestCase):
 
 class DistributedCircuitTestCase(MediaTestCase, unittest.TestCase):
     def setUp(self):
-        self.frequency = rf.Frequency(75,110,101,'ghz')
+        self.frequency = rf.Frequency(75,110,101,'GHz')
         self.media = DistributedCircuit(\
             frequency=self.frequency,
             L=1,C=1,R=0,G=0
@@ -127,7 +168,8 @@ suite.addTests([\
     loader.loadTestsFromTestCase(CPWTestCase),
     loader.loadTestsFromTestCase(RectangularWaveguideTestCase),
     loader.loadTestsFromTestCase(DistributedCircuitTestCase),
+    loader.loadTestsFromTestCase(Z0InitDeprecationTestCase),
     ])
 
 #suite = unittest.TestLoader().loadTestsFromTestCase(FreespaceTestCase)
-unittest.TextTestRunner(verbosity=2).run(suite)
+unittest.TextTestRunner(verbosity=2).run(suite)
\ No newline at end of file
