@@ -5,7 +5,7 @@ import pytest
 import skrf as rf
 from skrf.media import Coaxial
 import numpy as npy
-from numpy.testing import assert_almost_equal, assert_array_almost_equal, run_module_suite
+from numpy.testing import assert_almost_equal, assert_array_almost_equal
 
 class MediaTestCase(unittest.TestCase):
     """
@@ -31,11 +31,11 @@ class MediaTestCase(unittest.TestCase):
 
         a_media = Coaxial(
             frequency = qucs_ntwk.frequency,
-            Dint=1e-3, Dout=3e-3, epsilon_r=2.29, \
-            tan_delta=4e-4, sigma=1./1.68e-8 \
+            Dint=1e-3, Dout=3e-3, epsilon_r=2.29,
+            tan_delta=4e-4, sigma=1./1.68e-8,
+            z0_port = 50.
             )
-        skrf_ntwk = a_media.thru(z0=50)**a_media.line(200e-3,'m')\
-                    **a_media.thru(z0=50)
+        skrf_ntwk = a_media.line(200e-3,'m')
         # Equal assertion fails if tan_delta or resistivity are non-zero
         #self.assertEqual(qucs_ntwk, skrf_ntwk)
         self.assertTrue(
@@ -71,13 +71,19 @@ class MediaTestCase(unittest.TestCase):
         coax = Coaxial.from_attenuation_VF(frequency=frequency, VF=1, att=_att, unit='Np/feet')
         assert_almost_equal(coax.gamma.real,  _att*rf.meter_2_feet())
 
+        with self.assertRaises(ValueError):
+            coax = Coaxial.from_attenuation_VF(frequency=frequency, VF=1, att=npy.array([.1, .2]), unit='Np/feet')
+        frequency = rf.Frequency(1., 1.1, unit='GHz', npoints=2)
+        coax = Coaxial.from_attenuation_VF(frequency=frequency, VF=1, att=npy.array([.1, .2]), unit='Np/feet')
+        self.assertEqual( coax.frequency.f.shape, (2,))
+
 
     def test_init_from_attenuation_VF_array_att(self):
         """
         Test passing array as attenuation in the Coaxial classmethod
         `from_attenuation_VF_units`.
         """
-        # create a Coaxial media for frequency-dependent attenuation and 
+        # create a Coaxial media for frequency-dependent attenuation and
         # test the resulting alpha values (real part of gamma)
         frequency = rf.Frequency(start=1, stop=2, unit='GHz', npoints=101)
         # k0k1k2 attenuation model
@@ -100,7 +106,8 @@ class MediaTestCase(unittest.TestCase):
 
         rho = 1e-7
         dint = 0.44e-3
-        coax = Coaxial(freq, z0=50, Dint=dint, Dout=1.0e-3, sigma=1/rho)
+        coax = Coaxial(freq, z0_port = 50, Dint = dint, Dout = 1.0e-3,
+                       sigma = 1/rho)
 
         dc_res = rho / (npy.pi * (dint/2)**2)
 
@@ -110,8 +117,4 @@ class MediaTestCase(unittest.TestCase):
             R_simple = coax.Rs/(2*npy.pi)*(1/coax.a + 1/coax.b)
 
             self.assertTrue(abs(1 - coax.R[0]/dc_res) < 1e-2)
-            self.assertTrue(abs(1 - coax.R[1]/R_simple[1]) < 1e-2)
-
-if __name__ == "__main__":
-    # Launch all tests
-    run_module_suite()
+            self.assertTrue(abs(1 - coax.R[1]/R_simple[1]) < 1e-2)
\ No newline at end of file
