@@ -1,13 +1,10 @@
 import unittest
 import os
 import numpy as npy
-from numpy.testing import run_module_suite
 
-
-from skrf.media import DefinedGammaZ0, Media
+from skrf.media import DefinedGammaZ0
 from skrf.network import Network
 from skrf.frequency import Frequency
-import skrf
 
 
 class DefinedGammaZ0TestCase(unittest.TestCase):
@@ -29,13 +26,16 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         """
         name = 'impedanceMismatch,50to25'
         qucs_ntwk = Network(os.path.join(self.files_dir, name + '.s2p'))
+        # sNp-files store the same impedance for every port, so to compare the
+        # networks, the port impedance has to be set manually to [50,25]
+        qucs_ntwk.z0 = [50,25]
         self.dummy_media.frequency = qucs_ntwk.frequency
         skrf_ntwk = self.dummy_media.thru(z0=50, name = name)**\
             self.dummy_media.thru(z0=25)
 
         self.assertEqual(qucs_ntwk, skrf_ntwk)
         self.assertEqual(qucs_ntwk.name, skrf_ntwk.name)
-        
+
     def test_tee(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -45,7 +45,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.tee(name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_splitter(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -55,7 +55,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.splitter(3, name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_thru(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -65,7 +65,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.thru(name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_line(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -75,7 +75,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.line(90, 'deg', name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_delay_load(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -86,7 +86,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         skrf_ntwk = self.dummy_media.delay_load(1j, 90, 'deg',
                                                       name = name)
         self.assertEqual(name, skrf_ntwk.name)
-    
+
     def test_shunt_delay_load(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -97,7 +97,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         skrf_ntwk = self.dummy_media.shunt_delay_load(1j, 90, 'deg',
                                                       name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_delay_open(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -107,7 +107,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.delay_open(90, 'deg', name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_shunt_delay_open(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -117,7 +117,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.shunt_delay_open(90, 'deg', name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_delay_short(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -127,7 +127,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.delay_short(90, 'deg', name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_shunt_delay_short(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -150,6 +150,28 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         skrf_ntwk = self.dummy_media.resistor(1, name = name)
         self.assertEqual(qucs_ntwk, skrf_ntwk)
         self.assertEqual(qucs_ntwk.name, skrf_ntwk.name)
+        # test vs analytical ABCD parameters of a series resistor
+        Z = 10 - 4j
+        ntwk = self.dummy_media.resistor(Z)
+        ABCD = npy.full(ntwk.s.shape, [[1, -1+1j],
+                                       [0, 1]])
+        ABCD[:,0,1] = Z
+        npy.testing.assert_array_almost_equal(ABCD, ntwk.a)
+
+    def test_shunt_resistor(self):
+        """
+        Test the naming of the network. When circuit is used to connect a
+        topology of networks, they should have unique names.
+        """
+        name = 'shunt_resistor,1ohm'
+        self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
+        skrf_ntwk = self.dummy_media.resistor(1, name = name)
+        self.assertEqual(name, skrf_ntwk.name)
+        # test vs analytical ABCD parameters of a shunt resistor
+        Z = 10 - 4j
+        ntwk = self.dummy_media.shunt_resistor(Z)
+        ABCD = npy.asarray([[[1, 0], [1/Z, 1]]])
+        npy.testing.assert_array_almost_equal(ABCD, ntwk.a)
 
     def test_capacitor(self):
         """
@@ -163,7 +185,15 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         skrf_ntwk = self.dummy_media.capacitor(.01e-12, name = name)
         self.assertEqual(qucs_ntwk, skrf_ntwk)
         self.assertEqual(qucs_ntwk.name, skrf_ntwk.name)
-        
+        # test vs analytical ABCD parameters of a series capacitor
+        C = 0.1e-12
+        ntwk = self.dummy_media.capacitor(C)
+        Z = 1/(1j*C*ntwk.frequency.w)
+        ABCD = npy.full(ntwk.s.shape, [[1, -1+1j],
+                                       [0, 1]])
+        ABCD[:,0,1] = Z
+        npy.testing.assert_array_almost_equal(ABCD, ntwk.a)
+
     def test_shunt_capacitor(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -173,7 +203,42 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.capacitor(.01e-12, name = name)
         self.assertEqual(name, skrf_ntwk.name)
+        # test vs analytical ABCD parameters of a shunt capacitor
+        C = 0.1e-12
+        ntwk = self.dummy_media.shunt_capacitor(C)
+        Z = 1/(1j*C*ntwk.frequency.w)
+        ABCD = npy.full(ntwk.s.shape, [[1, 0],
+                                       [-1+1j, 1]])
+        ABCD[:,1,0] = 1/Z
+        npy.testing.assert_array_almost_equal(ABCD, ntwk.a)
 
+    def test_capacitor_q(self):
+        """
+        Compare the component values against s-parameters generated by ADS.
+        Test the naming of the network. When circuit is used to connect a
+        topology of networks, they should have unique names.
+        """
+        name = 'capacitor_q'
+        ads_path = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            'ads'
+            )
+        ads_ntwk = Network(os.path.join(ads_path, name + '.s2p'))
+        self.dummy_media.frequency = ads_ntwk.frequency
+        skrf_ntwk = self.dummy_media.capacitor_q(C=1.0e-12, f_0=1.0e9, q_factor=30.0, name = name)
+        self.assertEqual(ads_ntwk, skrf_ntwk)
+        self.assertEqual(ads_ntwk.name, skrf_ntwk.name)
+        # test vs analytical ABCD parameters of a series capacitor with q_factor
+        C = 0.1e-12
+        Q = 30.0
+        F = 1.0e9
+        ntwk = self.dummy_media.capacitor_q(C=C, f_0=F, q_factor=Q)
+
+        Z = 1/(2*npy.pi*F*C/Q+1j*C*ntwk.frequency.w)
+        ABCD = npy.full(ntwk.s.shape, [[1, -1+1j],
+                                       [0, 1]])
+        ABCD[:,0,1] = Z
+        npy.testing.assert_array_almost_equal(ABCD, ntwk.a)
 
     def test_inductor(self):
         """
@@ -187,7 +252,15 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         skrf_ntwk = self.dummy_media.inductor(.1e-9, name = name)
         self.assertEqual(qucs_ntwk, skrf_ntwk)
         self.assertEqual(qucs_ntwk.name, skrf_ntwk.name)
-        
+        # test vs analytical ABCD parameters of a series inductor
+        L = 0.1e-9
+        ntwk = self.dummy_media.inductor(L)
+        Z = 1j*L*ntwk.frequency.w
+        ABCD = npy.full(ntwk.s.shape, [[1, -1+1j],
+                                       [0, 1]])
+        ABCD[:,0,1] = Z
+        npy.testing.assert_array_almost_equal(ABCD, ntwk.a)
+
     def test_shunt_inductor(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -197,7 +270,49 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.inductor(.1e-9, name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+        # test vs analytical ABCD parameters of a shunt inductor
+        L = 0.1e-9
+        ntwk = self.dummy_media.shunt_inductor(L)
+        Z = 1j*L*ntwk.frequency.w
+        ABCD = npy.full(ntwk.s.shape, [[1, 0],
+                                       [1-1j, 1]])
+        ABCD[:,1,0] = 1/Z
+        npy.testing.assert_array_almost_equal(ABCD, ntwk.a)
+
+    def test_inductor_q(self):
+        """
+        Compare the component values against s-parameters generated by ADS.
+        Test the naming of the network. When circuit is used to connect a
+        topology of networks, they should have unique names.
+        """
+        name = 'inductor_q'
+        ads_path = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            'ads'
+            )
+        ads_ntwk = Network(os.path.join(ads_path, name + '.s2p'))
+        self.dummy_media.frequency = ads_ntwk.frequency
+        skrf_ntwk = self.dummy_media.inductor_q(L=1.0e-9, f_0=1.0e9, q_factor=30.0, name = name)
+        self.assertEqual(ads_ntwk, skrf_ntwk)
+        self.assertEqual(ads_ntwk.name, skrf_ntwk.name)
+        # test vs analytical ABCD parameters of a series capacitor with q_factor
+        L = 0.1e-9
+        Q = 30.0
+        F = 1.0e9
+        ntwk = self.dummy_media.inductor_q(L=L, f_0=F, q_factor=Q)
+        rdc = F*0.05*(2 * npy.pi)*L/Q
+        w_q = 2*npy.pi*F
+        rq1 = w_q*L/Q
+        rq2 = npy.sqrt(rq1**2-rdc**2)
+        qt = w_q*L/rq2
+        rac = ntwk.frequency.w*L/qt
+
+        Z = npy.sqrt(rdc**2+rac**2)+1j*ntwk.frequency.w*L
+        ABCD = npy.full(ntwk.s.shape, [[1, -1+1j],
+                                       [0, 1]])
+        ABCD[:,0,1] = Z
+        npy.testing.assert_array_almost_equal(ABCD, ntwk.a)
+
     def test_attenuator(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -208,7 +323,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         skrf_ntwk = self.dummy_media.attenuator(-10, d = 90, unit = 'deg',
                                                 name = name)
         self.assertEqual(name, skrf_ntwk.name)
-        
+
     def test_lossless_mismatch(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -218,7 +333,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.dummy_media.frequency = Frequency(1, 1, 1, unit='GHz')
         skrf_ntwk = self.dummy_media.lossless_mismatch(-10, name = name)
         self.assertEqual(name, skrf_ntwk.name)
-    
+
     def test_isolator(self):
         """
         Test the naming of the network. When circuit is used to connect a
@@ -253,7 +368,7 @@ class DefinedGammaZ0TestCase(unittest.TestCase):
         self.assertEqual(len(freq), len(a))
         self.assertEqual(len(freq), len(a.gamma))
         self.assertEqual(len(freq), len(a.z0))
-        
+
     def test_write_csv(self):
         fname = os.path.join(self.files_dir,\
                 'out.csv')
@@ -521,21 +636,21 @@ class DefinedGammaZ0_s_def(unittest.TestCase):
         m = DefinedGammaZ0(
             frequency = Frequency(1, 1, 1, unit='ghz'),
             gamma=1j,
-            z0 = 50,
-            Z0 = 10+20j,
+            z0_port = 50,
+            z0 = 10+20j,
             )
-        self.assertTrue(m.Z0.imag != 0)
+        self.assertTrue(m.z0.imag != 0)
 
         # Powerwave short is -Z0.conj()/Z0
-        short = m.short(z0=m.Z0, s_def='power')
+        short = m.short(z0=m.z0, s_def='power')
         self.assertTrue(short.s != -1)
         # Should be -1 when converted to traveling s_def
         npy.testing.assert_allclose(short.s_traveling, -1)
 
-        short = m.short(z0=m.Z0, s_def='traveling')
+        short = m.short(z0=m.z0, s_def='traveling')
         npy.testing.assert_allclose(short.s, -1)
 
-        short = m.short(z0=m.Z0, s_def='pseudo')
+        short = m.short(z0=m.z0, s_def='pseudo')
         npy.testing.assert_allclose(short.s, -1)
 
         # Mismatches agree with real port impedances
@@ -562,8 +677,4 @@ class DefinedGammaZ0_s_def(unittest.TestCase):
 
         npy.testing.assert_allclose(thru_traveling.s, mismatch_traveling.s, rtol=1e-3)
         npy.testing.assert_allclose(thru_pseudo.s, mismatch_pseudo.s, rtol=1e-3)
-        npy.testing.assert_allclose(thru_power.s, mismatch_power.s, rtol=1e-3)
-
-if __name__ == "__main__":
-    # Launch all tests
-    run_module_suite()
+        npy.testing.assert_allclose(thru_power.s, mismatch_power.s, rtol=1e-3)
\ No newline at end of file
