@@ -29,9 +29,10 @@ class MediaTestCase(unittest.TestCase):
         qucs_ntwk = Network(fname)
         wg = RectangularWaveguide(
             frequency = qucs_ntwk.frequency,
-            a = 100*mil
+            a = 100*mil,
+            z0_override = 50.
             )
-        skrf_ntwk = wg.thru(Z0=50)**wg.line(200*mil,'m')**wg.thru(Z0=50)
+        skrf_ntwk = wg.line(200*mil,'m')
         self.assertEqual(qucs_ntwk, skrf_ntwk)
 
 
@@ -46,7 +47,7 @@ class MediaTestCase(unittest.TestCase):
         wg = RectangularWaveguide(
             frequency = ntwk.frequency,
             a=15*mil,
-            z0=50,
+            z0_override=50,
             rho = 1/(3.8e7),
             )
         self.assertTrue(
@@ -62,9 +63,9 @@ class MediaTestCase(unittest.TestCase):
         wg = RectangularWaveguide(
             ntwk.frequency,
             a=15*mil,
-            z0=50,
+            z0_override=50,
             rho = 1/(3.8e7),
             roughness = 100e-9,
             )
         self.assertTrue(
-            max(abs(wg.line(1,'in').s_mag[:,1,0] - ntwk.s_mag[:,1,0]))<1e-3 )
+            max(abs(wg.line(1,'in').s_mag[:,1,0] - ntwk.s_mag[:,1,0]))<1e-3)
