@@ -1,18 +1,20 @@
 from .frequency import Frequency
 from .mathFunctions import *
 from .plotting import plot_complex_rectangular,plot_rectangular, smith
-from .util import get_fid, get_extn, find_nearest_index,slice_domain
+from .util import find_nearest_index,slice_domain
 
 from scipy import  signal
 import numpy as npy
 from numpy import fft
-import matplotlib.pyplot as plb
+
+try:
+    import matplotlib.pyplot as plb
+except ImportError:
+    pass
 
 from IPython.display import Image
 from IPython.core.pylabtools import print_figure
 
-from abc import ABCMeta, abstractmethod
-from copy import deepcopy
 import re
 
 
