@@ -78,19 +78,19 @@ the coupling factor, then measure :math:`Q_L` from the 3 dB bandwidth
 and using the relationships above.
 
 Fortunately, scikit-rf implements methods for determining loaded and
-unloaded Q-factors from frequency-domain S-parameters. The implemented methods 
-are described in detail in [MAT58]_, and can be applied to measurements of 
+unloaded Q-factors from frequency-domain S-parameters. The implemented methods
+are described in detail in [MAT58]_, and can be applied to measurements of
 transmission or reflection.
 
 Q-factor determination through equivalent-circuit models
 --------------------------------------------------------
 Characterisation of resonances from measurements in the frequency-domain
 can be achieved through equivalent-circuit models [MAT58]_. Resonators can be
-modelled as an ideal RLC resonator connected to an external circuit, 
+modelled as an ideal RLC resonator connected to an external circuit,
 incorporating elements to account for a lossy coupling and coupling reactances.
 
-For high Q-factor resonators (in practice, :math:`Q_L` > 100), the S-parameter 
-response of a resonator measured in a calibrated system with reference planes 
+For high Q-factor resonators (in practice, :math:`Q_L` > 100), the S-parameter
+response of a resonator measured in a calibrated system with reference planes
 at the resonator couplings can be expressed like [MAT58]_, [Galwas]_ :
 
 .. math::
@@ -342,8 +342,8 @@ class Qfactor:
             result = self._optimise_fit8(self.N)
 
         # overwrite results in self
-        self.Q_L = float(result.Q_L)
-        self.f_L = float(result.f_L)
+        self.Q_L = result.Q_L
+        self.f_L = result.f_L
         self.fitted = True
         self.opt_res = result
 
@@ -462,12 +462,12 @@ class Qfactor:
             t = 2.0 * (self.f[i] / f_L0 - 1.0)
             y = 1.0 / complex(1.0, Q_L0 * t)
             v = t * y
-            v1 = y * self.s[i]
+            v1 = y * self.s[i, 0, 0]
             G[i] = v1.real
             G[i2] = v1.imag
             v2 = v1 * t
-            M[i, :] = np.array([v.real, -v.imag, y.real, -y.imag, v2.imag], dtype="object")
-            M[i2, :] = np.array([v.imag, v.real, y.imag, y.real, -v2.real], dtype="object")
+            M[i, :] = np.array([v.real, -v.imag, y.real, -y.imag, v2.imag])
+            M[i2, :] = np.array([v.imag, v.real, y.imag, y.real, -v2.real])
 
         T = M.transpose()  # unweighted
         C = T @ M
@@ -475,9 +475,9 @@ class Qfactor:
         sv = np.linalg.solve(C, q)
         a_re, a_im, b_re, b_im, Q_L = sv
 
-        self._a = a_re + 1j*a_im
-        self._b = b_re + 1j*b_im
-        self.Q_L = Q_L
+        self._a = (a_re + 1j*a_im)[0]
+        self._b = (b_re + 1j*b_im)[0]
+        self.Q_L = Q_L[0]
         self.f_L = f_L0
 
         if self.verbose:
@@ -563,7 +563,7 @@ class Qfactor:
                 T = np.multiply(X, PV2)
                 C = np.dot(T, M)
                 q = np.dot(T, G)
-                dm = np.linalg.solve(C, q)
+                dm = np.linalg.solve(C, q)[:,0]
                 m1 += dm[0]
                 m2 += dm[1]
                 m3 += dm[2]
@@ -724,7 +724,7 @@ class Qfactor:
                         -ym.imag,
                         u.real,
                         u2.real,
-                        -u3.imag], dtype="object"
+                        -u3.imag]
                     )
                     M[i2, :] = np.array(
                         [expm7.imag,
@@ -733,7 +733,7 @@ class Qfactor:
                         ym.real,
                         u.imag,
                         u2.imag,
-                        u3.real], dtype="object"
+                        u3.real]
                     )
                     r = self.s[i] - v  # residual
                     G[i] = r.real
@@ -742,7 +742,7 @@ class Qfactor:
                 T = np.multiply(X, PV2)
                 C = np.dot(T, M)
                 q = np.dot(T, G)
-                dm = np.linalg.solve(C, q)
+                dm = np.linalg.solve(C, q)[:,0]
                 m1 += dm[0]
                 m2 += dm[1]
                 m3 += dm[2]
@@ -897,8 +897,8 @@ class Qfactor:
                     u2 = -u * self.f[i] / Flwst
                     FL = Flwst * m5 / m6
                     t = 2 * (self.f[i] - FL) / FL
-                    M[i, :] = np.array([1.0, 0.0, y.real, -y.imag, u.real, u2.real, t, 0.0], dtype="object")
-                    M[i2, :] = np.array([0.0, 1.0, y.imag, y.real, u.imag, u2.imag, 0.0, t], dtype="object")
+                    M[i, :] = np.array([1.0, 0.0, y.real, -y.imag, u.real, u2.real, t, 0.0])
+                    M[i2, :] = np.array([0.0, 1.0, y.imag, y.real, u.imag, u2.imag, 0.0, t])
                     v = c2 + c3 * y + (m8 + 1j * m9) * t
                     r = self.s[i] - v  # residual
                     G[i] = r.real
@@ -907,7 +907,7 @@ class Qfactor:
                 T = np.multiply(X, PV2)
                 C = np.dot(T, M)
                 q = np.dot(T, G)
-                dm = np.linalg.solve(C, q)
+                dm = np.linalg.solve(C, q)[:,0]
                 m1 += dm[0]
                 m2 += dm[1]
                 m3 += dm[2]
@@ -981,7 +981,7 @@ class Qfactor:
         ----------
        opt_res : None or :class:`~skrf.qfactor.OptimizedResult`. Default is None.
            Solution produced by the :meth:`~skrf.qfactor.Qfactor.fit` method.
-           If None, uses the solution previously calculated, if performed. 
+           If None, uses the solution previously calculated, if performed.
         A : None of float. Default is None.
             Scaling factor as defined in MAT 58 [MAT58]_.
             For `reflection` resonance type, can be set as None
@@ -1005,7 +1005,7 @@ class Qfactor:
 
         """
         # if no solution passed, use internal solution if exist
-        if opt_res is None: 
+        if opt_res is None:
             if self.opt_res is None:
                 raise ValueError('No solution found or passed.')
             else:
@@ -1043,7 +1043,7 @@ class Qfactor:
         ----------
        opt_res : None or :class:`~skrf.qfactor.OptimizedResult`. Default is None.
            Solution produced by the :meth:`~skrf.qfactor.Qfactor.fit` method.
-           If None, uses the solution previously calculated, if performed. 
+           If None, uses the solution previously calculated, if performed.
         A : float or None. Default is None.
             Scaling factor as defined in MAT 58 [MAT58]_.
             For `reflection` resonance type, can be set as None
@@ -1062,7 +1062,7 @@ class Qfactor:
 
         """
         # if no solution passed, use internal solution if exist
-        if opt_res is None: 
+        if opt_res is None:
             if self.opt_res is None:
                 raise ValueError('No solution found or passed.')
             else:
@@ -1160,7 +1160,7 @@ class Qfactor:
         ----------
        opt_res : None or :class:`~skrf.qfactor.OptimizedResult`. Default is None.
            Solution produced by the :meth:`~skrf.qfactor.Qfactor.fit` method.
-           If None, uses the solution previously calculated, if performed. 
+           If None, uses the solution previously calculated, if performed.
         f : None or np.ndarray. Default is None.
             frequency array [Hz]. If None, use the self frequencies.
 
@@ -1178,7 +1178,7 @@ class Qfactor:
 
         """
         # if no solution passed, use internal solution if exist
-        if opt_res is None: 
+        if opt_res is None:
             if self.opt_res is None:
                 raise ValueError('No solution found or passed.')
             else:
@@ -1206,7 +1206,7 @@ class Qfactor:
         ----------
         opt_res : None or :class:`~skrf.qfactor.OptimizedResult`. Default is None.
             Solution produced by the :meth:`~skrf.qfactor.Qfactor.fit` method.
-            If None, uses the solution previously calculated, if performed. 
+            If None, uses the solution previously calculated, if performed.
         frequency : None or :class:`~skrf.frequency.Frequency`. Default is None.
             Frequency for the fitted Network. If None, use the same
             Frequency than the one used to create the QFactor.
@@ -1218,7 +1218,7 @@ class Qfactor:
 
         """
         # if no solution passed, use internal solution if exist
-        if opt_res is None: 
+        if opt_res is None:
             if self.opt_res is None:
                 raise ValueError('No solution found or passed.')
             else:
@@ -1241,7 +1241,7 @@ class Qfactor:
         -------
         float
             Resonant frequency in the frequency unit.
-            
+
         See Also
         --------
         f_L : Resonant Frequency in Hz.
@@ -1293,4 +1293,4 @@ class Qfactor:
         """
         if not self.fitted:
             warn('Q-factor not fitted, result may be inaccurate. Use the .fit() method before.')
-        return self.BW/self.f_multiplier
\ No newline at end of file
+        return self.BW/self.f_multiplier
