@@ -1,4 +1,3 @@
-import py
 import pytest
 from skrf.frequency import Frequency, InvalidFrequencyWarning
 import unittest
@@ -8,6 +7,7 @@ import tempfile
 import zipfile
 import sys
 import numpy as npy
+from scipy import signal
 from pathlib import Path
 import pickle
 import skrf as rf
@@ -18,6 +18,7 @@ from skrf.media import CPW
 from skrf.media import DistributedCircuit
 from skrf.constants import S_DEFINITIONS
 from skrf.networkSet import tuner_constellation
+from skrf.constants import S_DEF_HFSS_DEFAULT
 try:
     from skrf.plotting import plot_contour
 except ImportError:
@@ -66,6 +67,17 @@ class NetworkTestCase(unittest.TestCase):
         self.Fix2 = rf.concat_ports([l1, l1, l1, l1], port_order='first')
         self.DUT2 = rf.concat_ports([l2, l2, l2, l2], port_order='first')
         self.Meas2 = rf.concat_ports([l3, l3, l3, l3], port_order='first')
+        self.fet = rf.Network(os.path.join(self.test_dir, 'fet.s2p'))
+
+    def test_network_copy(self):
+        n = self.ntwk1
+        n2 = n.copy()
+        self.assertEqual( n.frequency, n2.frequency)
+        self.assertNotEqual( id(n.frequency), id(n2.frequency))
+        self.assertNotEqual( id(n.frequency.f), id(n2.frequency.f))
+
+        n.frequency.f[0] = 0
+        self.assertNotEqual(n2.frequency.f[0], 0)
 
     def test_two_port_reflect(self):
         number_of_data_points = 10
@@ -84,12 +96,22 @@ class NetworkTestCase(unittest.TestCase):
         t = self.ntwk1.s11.s_time
         s = self.ntwk1.s11.s
         self.assertTrue(len(t)== len(s))
-    
+
     def test_time_gate(self):
         ntwk = self.ntwk1
         gated = self.ntwk1.s11.time_gate(0,.2, t_unit='ns')
         self.assertTrue(len(gated)== len(ntwk))
 
+    def test_time_gate_custom_window(self):
+        for window in ["hamming", ('kaiser', 6)]:
+            gated1 = self.ntwk1.s11.time_gate(0,.2, t_unit='ns', window=window, fft_window=window)
+
+            def get_window(*args, **kwargs):
+                return signal.get_window(window, *args, **kwargs)
+        
+            gated2 = self.ntwk1.s11.time_gate(0,.2, t_unit='ns', window=get_window, fft_window=get_window)
+            assert gated1 == gated2
+
     def test_time_gate_raises(self):
         ntwk = self.ntwk1
         with pytest.warns(DeprecationWarning, match="Time unit not passed"):
@@ -112,8 +134,8 @@ class NetworkTestCase(unittest.TestCase):
         gated = ntwk.s11.time_gate()
         self.assertTrue(len(gated)== len(ntwk))
 
-    
-    def test_time_transform(self):
+
+    def test_time_transform_v2(self):
         spb = (4, 5)
         data_rate = 5e9
         num_taps = (100, 101)
@@ -319,18 +341,9 @@ class NetworkTestCase(unittest.TestCase):
         with pytest.raises(ValueError) as e_info:
             snp = ntwk.write_touchstone(return_string=True)
 
-        ntwk.s_def = 'power'
-        # Should raise warning when write_z0 and s_def != 'traveling'.
-        with warnings.catch_warnings(record=True) as w:
-            warnings.simplefilter("always")
-            snp = ntwk.write_touchstone(return_string=True, write_z0=True)
-            self.assertTrue(len(w) == 1)
-
-        ntwk.s_def = 'traveling'
-        # Ok if write_z0 specified
+        # Writing Touchstone and reading it back
         snp = ntwk.write_touchstone(return_string=True, write_z0=True)
 
-        # Test reading it back
         strio = io.StringIO(snp)
         # Required for reading touchstone file
         strio.name = f'StringIO.s{ports}p'
@@ -368,6 +381,27 @@ class NetworkTestCase(unittest.TestCase):
         # Writing complex characteristic impedance should fail
         with pytest.raises(ValueError) as e_info:
             snp = ntwk.write_touchstone(return_string=True)
+        
+    def test_write_touchstone_noisy(self):
+        ntwk = rf.Network(os.path.join(self.test_dir,'ntwk_noise.s2p'))
+
+        # Read back the written touchstone
+        ntwkstr = ntwk.write_touchstone(return_string=True)
+        strio = io.StringIO(ntwkstr)
+        strio.name = f'StringIO.s2p'
+        new_ntwk = rf.Network(strio)
+
+        # Only compare to original noise data, not interpolated
+        ntwk.resample(ntwk.f_noise)
+        new_ntwk.resample(new_ntwk.f_noise)
+        
+        # Newly written noise properties should match the original
+        npy.testing.assert_allclose(ntwk.f_noise.f_scaled, new_ntwk.f_noise.f_scaled)
+        npy.testing.assert_allclose(ntwk.nfmin, new_ntwk.nfmin)
+        npy.testing.assert_allclose(ntwk.nfmin_db, new_ntwk.nfmin_db)
+        npy.testing.assert_allclose(ntwk.g_opt, new_ntwk.g_opt)
+        npy.testing.assert_allclose(ntwk.rn, new_ntwk.rn)
+        npy.testing.assert_allclose(ntwk.z0, new_ntwk.z0)
 
     def test_pickling(self):
         original_ntwk = self.ntwk1
@@ -552,6 +586,72 @@ class NetworkTestCase(unittest.TestCase):
                 self.assertTrue((net.z0 == net[0].z0).all())
                 self.assertTrue(net.s_def != net[0].s_def)
 
+    def test_max_stable_gain(self):
+        # Check whether the maximum stable gain agrees with that derived from Y-parameters
+        y12 = self.fet.y[:, 0, 1]
+        y21 = self.fet.y[:, 1, 0]
+        # Maximum stable gain derived from Y-parameters
+        gms_y = npy.abs(y21) / npy.abs(y12)
+        self.assertTrue(
+            npy.all(
+                npy.abs(self.fet.max_stable_gain - gms_y) < 1e-6
+            )
+        )
+
+        # Check whether a runtime warning is raised when zero division occurs
+        net = rf.Network(f=[1], s=[[0, 0],[0, 0]], z0=50)
+        with pytest.raises(RuntimeWarning):
+            net.max_stable_gain
+
+        # Check whether an error is raised when the network is not 2 port.
+        net = rf.Network(f=[1], s=npy.eye(3), z0=50)
+        with pytest.raises(ValueError):
+            net.max_stable_gain
+
+    def test_max_gain(self):
+        # Check whether the max gain agrees with that calculated with ADS
+        maxgain_ads = npy.loadtxt(os.path.join(self.test_dir, 'maxgain_ads.csv'), encoding='utf-8', delimiter=',')
+        self.assertTrue(
+            npy.all(
+                npy.abs(10 * npy.log10(self.fet.max_gain) - maxgain_ads[:,1]) < 1e-6
+            )
+        )
+
+        # Check whether a runtime warning is raised when zero division occurs
+        net = rf.Network(f=[1], s=[[0, 0],[0, 0]], z0=50)
+        with pytest.raises(RuntimeWarning):
+            net.max_gain
+
+        # Check whether an error is raised when the network is not 2 port.
+        net = rf.Network(f=[1], s=npy.eye(3), z0=50)
+        with pytest.raises(ValueError):
+            net.max_gain
+
+    def test_unilateral_gain(self):
+        # Check whether the unilateral gain agrees with that derived from Y-parameters
+        y11 = self.fet.y[:, 0, 0]
+        y12 = self.fet.y[:, 0, 1]
+        y21 = self.fet.y[:, 1, 0]
+        y22 = self.fet.y[:, 1, 1]
+        # Unilateral gain derived from Y-parameters
+        U_y = (npy.abs(y21 - y12) ** 2) \
+              / (4 * (npy.real(y11) * npy.real(y22) - npy.real(y12) * npy.real(y21)))
+        self.assertTrue(
+            npy.all(
+                npy.abs(self.fet.unilateral_gain - U_y) < 1e-6
+            )
+        )
+
+        # Check whether a runtime warning is raised when zero division occurs
+        net = rf.Network(f=[1], s=[[0, 0],[0, 0]], z0=50)
+        with pytest.raises(RuntimeWarning):
+            net.unilateral_gain
+
+        # Check whether an error is raised when the network is not 2 port.
+        net = rf.Network(f=[1], s=npy.eye(3), z0=50)
+        with pytest.raises(ValueError):
+            net.unilateral_gain
+
     def test_delay(self):
         ntwk1_delayed = self.ntwk1.delay(1,'ns',port=0)
         self.assertTrue(
@@ -663,12 +763,17 @@ class NetworkTestCase(unittest.TestCase):
         # Test that they are close with loose accuracy tolerance.
         for net in networks:
             for s_def in rf.S_DEFINITIONS:
-                npy.testing.assert_allclose(rf.z2s(rf.s2z(net.s, net.z0, s_def=s_def), net.z0, s_def=s_def), net.s, atol=1e-3)
-                npy.testing.assert_allclose(rf.y2s(rf.s2y(net.s, net.z0, s_def=s_def), net.z0, s_def=s_def), net.s, atol=1e-3)
+                npy.testing.assert_allclose(
+                    rf.z2s(rf.s2z(net.s, net.z0, s_def=s_def), net.z0, s_def=s_def), net.s, atol=1e-3
+                    )
+                npy.testing.assert_allclose(
+                    rf.y2s(rf.s2y(net.s, net.z0, s_def=s_def), net.z0, s_def=s_def), net.s, atol=1e-3
+                    )
 
     def test_conversions(self):
         #Converting to other format and back to S-parameters should return the original network
-        s_random = npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2))
+        s_random = npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2)) +\
+                   1j * npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2))
         ntwk_random = rf.Network(s=s_random, frequency=self.freq)
         for test_z0 in (50, 10, 90+10j, 4-100j):
             for test_ntwk in (self.ntwk1, self.ntwk2, self.ntwk3, ntwk_random):
@@ -683,15 +788,20 @@ class NetworkTestCase(unittest.TestCase):
     def test_multiport_conversions(self):
         #Converting to other format and back to S-parameters should return the original network
         for ports in range(3, 6):
-            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
+            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) +\
+                       1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
             test_ntwk = rf.Network(s=s_random, frequency=self.freq)
             random_z0 = npy.random.uniform(1, 100, (self.freq.npoints, ports)) +\
-            1j * npy.random.uniform(-100, 100, (self.freq.npoints, ports))
+                        1j * npy.random.uniform(-100, 100, (self.freq.npoints, ports))
             for test_z0 in (50, random_z0):
                 for s_def in rf.S_DEFINITIONS:
                     ntwk = rf.Network(s=test_ntwk.s, f=test_ntwk.f, z0=test_z0, s_def=s_def)
-                    npy.testing.assert_allclose(rf.z2s(rf.s2z(ntwk.s, test_z0, s_def=s_def), test_z0, s_def=s_def), ntwk.s)
-                    npy.testing.assert_allclose(rf.y2s(rf.s2y(ntwk.s, test_z0, s_def=s_def), test_z0, s_def=s_def), ntwk.s)
+                    npy.testing.assert_allclose(
+                        rf.z2s(rf.s2z(ntwk.s, test_z0, s_def=s_def), test_z0, s_def=s_def), ntwk.s
+                        )
+                    npy.testing.assert_allclose(
+                        rf.y2s(rf.s2y(ntwk.s, test_z0, s_def=s_def), test_z0, s_def=s_def), ntwk.s
+                        )
 
     def test_y_z_compatability(self):
         # Test that npy.linalg.inv(Z) == Y
@@ -727,7 +837,8 @@ class NetworkTestCase(unittest.TestCase):
     def test_sparam_renormalize(self):
         #Converting to other format and back to S-parameters should return the original network
         for ports in range(2, 6):
-            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
+            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) +\
+                       1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
             test_ntwk = rf.Network(s=s_random, frequency=self.freq)
             random_z0 = npy.random.uniform(1, 100, size=(self.freq.npoints, ports)) +\
                         1j*npy.random.uniform(-100, 100, size=(self.freq.npoints, ports))
@@ -744,7 +855,8 @@ class NetworkTestCase(unittest.TestCase):
         Test changing S-parameter definition with complex ports
         """
         for ports in range(2, 6):
-            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
+            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) +\
+                       1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
             test_ntwk = rf.Network(s=s_random, frequency=self.freq)
             random_z0 = npy.random.uniform(1, 100, size=(self.freq.npoints, ports)) +\
                         1j*npy.random.uniform(-100, 100, size=(self.freq.npoints, ports))
@@ -765,7 +877,8 @@ class NetworkTestCase(unittest.TestCase):
         after conversion with different method.
         """
         for ports in range(2, 6):
-            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
+            s_random = npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports)) +\
+                       1j * npy.random.uniform(-10, 10, (self.freq.npoints, ports, ports))
             test_ntwk = rf.Network(s=s_random, frequency=self.freq)
             random_z0 = npy.random.uniform(1, 100, size=(self.freq.npoints, ports)) +\
                         1j*npy.random.uniform(-100, 100, size=(self.freq.npoints, ports))
@@ -782,7 +895,8 @@ class NetworkTestCase(unittest.TestCase):
                     npy.testing.assert_allclose(ntwk_renorm.z0, ntwk.z0)
 
     def test_setters(self):
-        s_random = npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2)) + 1j * npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2))
+        s_random = npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2)) +\
+                   1j * npy.random.uniform(-10, 10, (self.freq.npoints, 2, 2))
         ntwk = rf.Network(s=s_random, frequency=self.freq)
         ntwk.z0 = npy.random.uniform(1, 100, len(ntwk.z0)) + 1j*npy.random.uniform(-100, 100, len(ntwk.z0))
         ntwk.s = ntwk.s
@@ -807,7 +921,7 @@ class NetworkTestCase(unittest.TestCase):
             1j*npy.random.uniform(-100, 100, self.freq.npoints)
         z0_array_freq_port = npy.random.uniform(1, 100, (self.freq.npoints,2)) +\
             1j*npy.random.uniform(-100, 100, (self.freq.npoints,2))
-            
+
         for z0 in [z0_scalar, z0_array_port, z0_array_freq, z0_array_freq_port]:
             ntwk = rf.Network(s=s_random, frequency=self.freq, z0=z0)
 
@@ -821,7 +935,7 @@ class NetworkTestCase(unittest.TestCase):
             npy.testing.assert_allclose(ntwk.s, s_random)
             ntwk.s_pseudo = s_pseudo
             npy.testing.assert_allclose(ntwk.s, s_random)
-    
+
             npy.testing.assert_allclose(ntwk.s_traveling, s_traveling)
             npy.testing.assert_allclose(ntwk.s_power, s_power)
             npy.testing.assert_allclose(ntwk.s_pseudo, s_pseudo)
@@ -905,6 +1019,27 @@ class NetworkTestCase(unittest.TestCase):
         self.assertTrue(ntw_power == ntw_pseudo)
         self.assertTrue(ntw_power == ntw_legacy)
 
+    def test_sparam_from_hfss_with_power_wave(self):
+        """
+        Open a Touchstone generated by HFSS with the power-wave definition.
+        """
+        pwfile = 'hfss_oneport_powerwave.s1p'
+        pwfile_skrf = 'tmp_skrf_oneport_powerwave.s1p'
+
+        # s_def must be explicitely passed as 'power',
+        # otherwise 'traveling' would have been assumed (being default HFSS setting)
+        ntwk_orig = rf.Network(os.path.join(self.test_dir, pwfile))
+        self.assertEqual(ntwk_orig.s_def, S_DEF_HFSS_DEFAULT)
+
+        ntwk_orig = rf.Network(os.path.join(self.test_dir, pwfile), s_def='power')
+        self.assertEqual(ntwk_orig.s_def, 'power')
+
+        # write Touchstone file and read it. Results should be the same
+        ntwk_orig.write_touchstone(os.path.join(self.test_dir, pwfile_skrf), write_z0=True, form='RI')
+        ntwk_skrf = rf.Network(os.path.join(self.test_dir, pwfile_skrf))
+
+        self.assertTrue(ntwk_orig == ntwk_skrf)
+
     def test_network_from_z_or_y(self):
         ' Construct a network from its z or y parameters '
         # test for both real and complex char. impedance
@@ -1057,7 +1192,7 @@ class NetworkTestCase(unittest.TestCase):
         self.assertTrue( ((a+2+2j).s == npy.array([[[3+4j]],[[5+6j]]])).all())
         # operating on list
         self.assertTrue( ((a+[1+1j,2+2j]).s == npy.array([[[2+3j]],[[5+6j]]])).all())
-     
+
 
     def test_interpolate(self):
         a = rf.N(f=[1,2],s=[1+2j, 3+4j],z0=1)
@@ -1248,7 +1383,8 @@ class NetworkTestCase(unittest.TestCase):
         self.assertTrue(abs(a.nfmin[0] - nf) < 1.e-6, 'noise figure does not match original spec')
         self.assertTrue(abs(a.z_opt[0] - 50.) < 1.e-6, 'optimal resistance does not match original spec')
         self.assertTrue(abs(a.rn[0] - 0.1159*50.) < 1.e-6, 'equivalent resistance does not match original spec')
-        self.assertTrue(npy.all(abs(a.g_opt) < 1.e-6), 'calculated optimal reflection coefficient does not match original coefficients')
+        self.assertTrue(npy.all(abs(a.g_opt) < 1.e-6),
+                        'calculated optimal reflection coefficient does not match original coefficients')
 
         b = rf.Network(f=[1, 2],
                        s=[[[0, 1], [1, 0]], [[0, 1], [1, 0]]],
@@ -1279,7 +1415,7 @@ class NetworkTestCase(unittest.TestCase):
         self.assertTrue(abs(a.z_opt[0] - 50.) < 1.e-6, 'optimal resistance was altered')
         self.assertTrue(abs(a.rn[0] - 0.1159*50.) < 1.e-6, 'equivalent resistance was altered')
 
-        tem = DistributedCircuit(z0=50)
+        tem = DistributedCircuit(z0_port = 50)
         inductor = tem.inductor(1e-9).interpolate(a.frequency)
 
         f = inductor ** a
@@ -1304,35 +1440,49 @@ class NetworkTestCase(unittest.TestCase):
     def test_noise_deembed(self):
 
 
-        f1_ =[75.5, 75.5] ; f2_=[75.5, 75.6] ; npt_ = [1,2]     # single freq and multifreq
+        f1_ =[75.5, 75.5]
+        f2_=[75.5, 75.6]
+        npt_ = [1,2]  # single freq and multifreq
         for f1,f2,npt in zip (f1_,f2_,npt_) :
           freq=rf.Frequency(f1,f2,npt,'ghz')
           ntwk4_n = rf.Network(os.path.join(self.test_dir,'ntwk4_n.s2p'), f_unit='GHz').interpolate(freq)
           ntwk4 = rf.Network(os.path.join(self.test_dir,'ntwk4.s2p'),f_unit='GHz').interpolate(freq)
           thru = rf.Network(os.path.join(self.test_dir,'thru.s2p'),f_unit='GHz').interpolate(freq)
 
-          ntwk4_thru = ntwk4 ** thru                  ;ntwk4_thru.name ='ntwk4_thru'
-          retrieve_thru =  ntwk4.inv ** ntwk4_thru    ;retrieve_thru.name ='retrieve_thru'
+          ntwk4_thru = ntwk4 ** thru
+          ntwk4_thru.name ='ntwk4_thru'
+          retrieve_thru =  ntwk4.inv ** ntwk4_thru
+          retrieve_thru.name ='retrieve_thru'
           self.assertEqual(retrieve_thru, thru)
           self.assertTrue(ntwk4_thru.noisy)
           self.assertTrue(retrieve_thru.noisy)
-          self.assertTrue((abs(thru.nfmin - retrieve_thru.nfmin)        < 1.e-6).all(), 'nf not retrieved by noise deembed')
-          self.assertTrue((abs(thru.rn    - retrieve_thru.rn)           < 1.e-6).all(), 'rn not retrieved by noise deembed')
-          self.assertTrue((abs(thru.z_opt - retrieve_thru.z_opt)        < 1.e-6).all(), 'noise figure does not match original spec')
+          self.assertTrue((abs(thru.nfmin - retrieve_thru.nfmin)        < 1.e-6).all(),
+                          'nf not retrieved by noise deembed')
+          self.assertTrue((abs(thru.rn    - retrieve_thru.rn)           < 1.e-6).all(),
+                          'rn not retrieved by noise deembed')
+          self.assertTrue((abs(thru.z_opt - retrieve_thru.z_opt)        < 1.e-6).all(),
+                          'noise figure does not match original spec')
 
-          ntwk4_n_thru = ntwk4_n ** thru                    ;ntwk4_n_thru.name ='ntwk4_n_thru'
-          retrieve_n_thru =  ntwk4_n.inv ** ntwk4_n_thru    ;retrieve_n_thru.name ='retrieve_n_thru'
+          ntwk4_n_thru = ntwk4_n ** thru
+          ntwk4_n_thru.name ='ntwk4_n_thru'
+          retrieve_n_thru =  ntwk4_n.inv ** ntwk4_n_thru
+          retrieve_n_thru.name ='retrieve_n_thru'
           self.assertTrue(ntwk4_n_thru.noisy)
           self.assertEqual(retrieve_n_thru, thru)
           self.assertTrue(ntwk4_n_thru.noisy)
           self.assertTrue(retrieve_n_thru.noisy)
-          self.assertTrue((abs(thru.nfmin - retrieve_n_thru.nfmin) < 1.e-6).all(), 'nf not retrieved by noise deembed')
-          self.assertTrue((abs(thru.rn    - retrieve_n_thru.rn)    < 1.e-6).all(), 'rn not retrieved by noise deembed')
-          self.assertTrue((abs(thru.z_opt - retrieve_n_thru.z_opt) < 1.e-6).all(), 'noise figure does not match original spec')
+          self.assertTrue((abs(thru.nfmin - retrieve_n_thru.nfmin) < 1.e-6).all(),
+                          'nf not retrieved by noise deembed')
+          self.assertTrue((abs(thru.rn    - retrieve_n_thru.rn)    < 1.e-6).all(),
+                          'rn not retrieved by noise deembed')
+          self.assertTrue((abs(thru.z_opt - retrieve_n_thru.z_opt) < 1.e-6).all(),
+                          'noise figure does not match original spec')
 
           tuner, x,y,g = tuner_constellation()
           newnetw = thru.copy()
-          nfmin_set=4.5; gamma_opt_set=complex(.7,-0.2); rn_set=1
+          nfmin_set=4.5
+          gamma_opt_set=complex(.7,-0.2)
+          rn_set=1
           newnetw.set_noise_a(thru.noise_freq, nfmin_db=nfmin_set, gamma_opt=gamma_opt_set, rn=rn_set )
           z = newnetw.nfdb_gs(g)[:,0]
           freq = thru.noise_freq.f[0]
@@ -1530,7 +1680,7 @@ class NetworkTestCase(unittest.TestCase):
             for n in range(ntwk.nports):
                 npy.testing.assert_array_almost_equal(
                     ntwk.s[:,m,n],
-                    ntwk.__getattribute__(f's{m+1}_{n+1}').s[:,0,0]
+                    getattr(ntwk, f's{m+1}_{n+1}').s[:,0,0]
                 )
 
 
@@ -1593,6 +1743,99 @@ class NetworkTestCase(unittest.TestCase):
         self.assertTrue(npy.allclose(net.s, s[:4]))
         self.assertFalse(npy.allclose(net.s.shape, s.shape))
 
+    def test_stability(self):
+        net = rf.Network(f=[1], s=[[0, 1],[0, 0]], z0=50)
+        self.assertTrue(net.stability == [npy.inf])
+
+        net = rf.Network(f=[1], s=[[0, 1],[1, 0]], z0=50)
+        self.assertTrue(net.stability == [1])
+
+        net = rf.Network(f=[1], s=npy.eye(3), z0=50)
+        with pytest.raises(ValueError):
+            net.stability
+
+    def test_equality(self):
+        s = npy.random.randn(10, 2, 2)
+        f1 = npy.arange(10)
+        f2 = npy.arange(10)
+        n1 = rf.Network(s=s,f=f1)
+        n2 = rf.Network(s=s,f=f2)
+        self.assertTrue(n1 == n2)
+
+        f2 = npy.arange(11)
+        n2 = rf.Network(s=s,f=f2)
+        self.assertFalse(n1 == n2)
+
+        f2 = npy.arange(10)
+        n2 = rf.Network(s=s,f=f2)
+        n2.s_def = 'pseudo'
+        self.assertTrue(n1 == n2)
+
+        n2.z0 = n2.z0 +npy.array([0+0.00001j])
+        self.assertTrue(n1 == n2)
+
+        n2.z0 = n2.z0 +npy.array([1+0j])
+        self.assertFalse(n1 == n2)
+
+        f2 = 10 * f1
+        n2 = rf.Network(s=s,f=f2)
+        self.assertFalse(n1 == n2)
+
+    def test_stability_circle(self):
+        # Check whether the load stability circle agrees with that calculated with ADS
+        load_stability_circle_ads = npy.loadtxt(os.path.join(self.test_dir, 'load_stability_circle_ads.csv'), encoding='utf-8', delimiter=',')
+        self.assertTrue(
+            npy.all(
+                npy.abs(rf.complex_2_magnitude(self.fet['30GHz'].stability_circle(target_port='load', npoints=6)[:,0]) - load_stability_circle_ads[:,0]) / load_stability_circle_ads[:,0] < 1e-4
+            )
+        )
+        self.assertTrue(
+            npy.all(
+                npy.abs(rf.complex_2_degree(self.fet['30GHz'].stability_circle(target_port='load', npoints=6)[:,0]) - load_stability_circle_ads[:,1]) / load_stability_circle_ads[:,1] < 1e-4
+            )
+        )
+
+        # Check whether the source stability circle agrees with that calculated with ADS
+        source_stability_circle_ads = npy.loadtxt(os.path.join(self.test_dir, 'source_stability_circle_ads.csv'), encoding='utf-8', delimiter=',')
+        self.assertTrue(
+            npy.all(
+                npy.abs(rf.complex_2_magnitude(self.fet['30GHz'].stability_circle(target_port='source', npoints=6)[:,0]) - source_stability_circle_ads[:,0]) / source_stability_circle_ads[:,0] < 1e-4
+            )
+        )
+        self.assertTrue(
+            npy.all(
+                npy.abs(rf.complex_2_degree(self.fet['30GHz'].stability_circle(target_port='source', npoints=6)[:,0]) - source_stability_circle_ads[:,1]) / source_stability_circle_ads[:,1] < 1e-4
+            )
+        )
+
+        # Check whether an error is raised when the network is not 2 port.
+        net = rf.Network(f=[1], s=npy.eye(3), z0=50)
+        with pytest.raises(ValueError):
+            net.stability_circle(target_port='load')
+
+        # Check whether an error is raised when the number of points is not positive.
+        with pytest.raises(ValueError):
+            net.stability_circle(target_port='load', npoints=0)
+
+        # Check whether an error is raised when an incorrect target_port is specified.
+        with pytest.raises(ValueError):
+            net.stability_circle(target_port='foobar')
+
+    def test_de_embed_by_floordiv(self):
+        ntwk_result_1 = self.ntwk1 // self.ntwk2
+        ntwk_result_2 = self.ntwk1 // (self.ntwk2)
+        np.testing.assert_array_equal(ntwk_result_1.s, ntwk_result_2.s)
+
+        # By definition A // B      => B.inv * A
+        # By definition A // [B, C] => B.inv * A * C.inv
+        # So, A // [B, C] should be equal to (A // B) * C.inv
+        ntwk_result_3 = self.ntwk1 // (self.ntwk2, self.ntwk3)
+        ntwk_result_4 = (self.ntwk1 // self.ntwk2) ** self.ntwk3.inv
+        np.testing.assert_array_almost_equal(ntwk_result_3.s, ntwk_result_4.s)
+
+        # Check weather an error is raised when more than two networks are specified
+        with pytest.raises(ValueError):
+            ntwk_result_3 = self.ntwk1 // (self.ntwk1, self.ntwk2, self.ntwk3)
 
 suite = unittest.TestLoader().loadTestsFromTestCase(NetworkTestCase)
 unittest.TextTestRunner(verbosity=2).run(suite)
