@@ -1,7 +1,6 @@
 import skrf as rf
 import unittest
 
-
 class HomoDictTest(unittest.TestCase):
     """
     """
@@ -17,7 +16,8 @@ class HomoDictTest(unittest.TestCase):
 
 
     def test_boolean_mask(self):
-        self.assertEqual(self.h[self.h.startswith('a')==True], 'asdf')
+        match_key = [key for key in self.h.keys() if self.h[key].startswith('a') ]
+        self.assertEqual(self.h[match_key], 'asdf')
 
 
 class HomoListTest(unittest.TestCase):
@@ -35,4 +35,5 @@ class HomoListTest(unittest.TestCase):
 
 
     def test_boolean_mask(self):
-        self.assertEqual(self.h[self.h.startswith('a')==True], 'asdf')
+        match_idx = [idx for idx in range(len(self.h)) if self.h.startswith('a')]
+        self.assertEqual(self.h[match_idx], 'asdf')
\ No newline at end of file
