@@ -14,9 +14,9 @@ Time domain functions
    detect_span
    find_n_peaks
    indexes
+   get_window
 
 """
-import scipy.signal
 
 from .util import find_nearest_index
 from scipy import signal
@@ -26,7 +26,7 @@ from scipy.ndimage import convolve1d
 import warnings
 
 # imports for type hinting
-from typing import List, TYPE_CHECKING
+from typing import List, TYPE_CHECKING, Union, Callable
 if TYPE_CHECKING:
     from .network import Network
 
@@ -191,10 +191,10 @@ def detect_span(ntwk: 'Network', t_unit: str = "") -> float:
     ----------
     ntwk : :class:`~skrf.network.Network`
         network to get data from
-    
+
     t_unit : str
-        Time unit for start, stop, center and span arguments, defaults to nanoseconds (ns).
-        
+        Time unit for start, stop, center and span arguments, defaults to seconds (s).
+
         Possible values:
             * 's': seconds
             * 'ms': milliseconds
@@ -211,13 +211,10 @@ def detect_span(ntwk: 'Network', t_unit: str = "") -> float:
     if t_unit == "":
         # Do not raise in autogate mode, where all parameters are None
         warnings.warn('''
-                        Time unit not passed: currently uses 'ns' per default.
-                        The future versions of scikit-rf will use 's' per default instead,
-                        so it is recommended to specify explicitly the time unit
-                        to obtain similar results with future versions.
+                        Time unit not passed: uses 's' per default.
                         ''',
                         DeprecationWarning, stacklevel=2)
-        t_unit = 'ns'
+        t_unit = 's'
 
     x = ntwk.s_time_db.flatten()
     p1, p2 = find_n_peaks(x, n=2)
@@ -226,7 +223,27 @@ def detect_span(ntwk: 'Network', t_unit: str = "") -> float:
 
     return span / time_lookup_dict[t_unit]
 
+def get_window(window: Union[str, tuple, Callable], Nx: int, **kwargs) -> npy.ndarray:
+    """Calls a custom window function or `scipy.signal.get_window()` depending on the window argument.
 
+    Parameters
+    ----------
+    window : str, tuple or Callable
+        The callable window function or a valid window string
+        for `scipy.signal.get_window()`.
+    Nx : int
+        Number of samples
+
+    Returns
+    -------
+    window : npy.ndarray
+        Window samples.
+    """
+
+    if callable(window):
+        return window(Nx, **kwargs)
+    else:
+        return signal.get_window(window, Nx=Nx, **kwargs)
 
 def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center: float = None, span: float = None,
               mode: str = 'bandpass', window=('kaiser', 6),
@@ -234,14 +251,15 @@ def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center:
     """
     Time-domain gating of one-port s-parameters with a window function from scipy.signal.windows.
 
-    The gate can be defined with start/stop times, or by center/span. All times are in units of nanoseconds but
-    can be changed using the `t_unit` parameter. The default unit will change to `s` in **scikit-rf** version 1.0.
+    The gate can be defined with start/stop times, or by center/span. All times are in units of seconds but
+    can be changed using the `t_unit` parameter.
     Common windows are:
 
     * ('kaiser', 6)
     * 6 # integers are interpreted as kaiser beta-values
     * 'hamming'
     * 'boxcar'  # a straight up rect
+    * Callable function which accepts integer with window size as argument
 
     If no parameters are passed this will try to auto-gate the largest
     peak.
@@ -263,7 +281,7 @@ def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center:
     mode : ['bandpass', 'bandstop']
         mode of gate
     window : string, float, or tuple
-        passed to `window` arg of `scipy.signal.get_window()`
+        passed to `window` arg of `scipy.signal.get_window()` or callable function
     method : str
         Gating method. There are 3 option: 'convolution', 'fft', 'rfft'.
 
@@ -272,7 +290,7 @@ def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center:
 
         With *'fft'* (default), the data gets transformed into time-domain using inverse FFT and the gating is achieved
         by multiplication with the time-domain gate. The gated time-domain signal is then transformed back into
-        frequency-domain using inverse FFT. As only positive signal frequencies are considered for the inverse FFT
+        frequency-domain using FFT. As only positive signal frequencies are considered for the inverse FFT
         (with or without a dc component), the resulting time-domain signal has the same number of samples as in the
         frequency-domain, but is complex-valued. This method is also know as *time-domain band-pass mode*.
 
@@ -294,10 +312,10 @@ def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center:
         the boundaries. This has a large effect on the generation of gating artefacts due to boundary effects. The
         optimal mode depends on the data. See the parameter description of `scipy.ndimage.convolve1d` for the available
         options.
-    
+
     t_unit : str
-        Time unit for start, stop, center and span arguments, defaults to nanoseconds (ns).
-        
+        Time unit for start, stop, center and span arguments, defaults to seconds (s).
+
         Possible values:
             * 's': seconds
             * 'ms': milliseconds
@@ -332,13 +350,10 @@ def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center:
         if not all([e is None for e in [start, stop, center, span]]):
             # Do not raise in autogate mode, where all parameters are None
             warnings.warn('''
-                            Time unit not passed: currently uses 'ns' per default.
-                            The future versions of scikit-rf will use 's' per default instead,
-                            so it is recommended to specify explicitly the time unit
-                            to obtain similar results with future versions.
+                            Time unit not passed: uses 's' per default.
                             ''',
                             DeprecationWarning, stacklevel=2)
-        t_unit = 'ns'
+        t_unit = 's'
 
     t_mult = time_lookup_dict[t_unit]
 
@@ -378,7 +393,7 @@ def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center:
         n_td = n_fd
         if fft_window is not None:
             # create band-pass window (zero on both lower and upper limit, one at center)
-            window_fd = signal.get_window(fft_window, n_fd)
+            window_fd = get_window(fft_window, n_fd)
         else:
             # create dummy-window
             window_fd = npy.ones(n_fd)
@@ -394,7 +409,7 @@ def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center:
         n_td = 2 * n_fd - 1
         if fft_window is not None:
             # create low-pass window (one at lower limit at f=0, zero on upper limit)
-            window_fd = signal.get_window(fft_window, 2 * n_fd)
+            window_fd = get_window(fft_window, 2 * n_fd)
             window_fd = window_fd[n_fd:]
         else:
             # create dummy-window
@@ -407,19 +422,18 @@ def time_gate(ntwk: 'Network', start: float = None, stop: float = None, center:
     ntwk_gated.s[:, 0, 0] = ntwk_gated.s[:, 0, 0] * window_fd
 
     # create time vector
-    t = npy.linspace(-0.5 / df, 0.5 / df, n_td)
-
+    t = npy.fft.fftshift(npy.fft.fftfreq(n_td, df))
     # find start/stop gate indices
     start_idx = find_nearest_index(t, start)
     stop_idx = find_nearest_index(t, stop)
 
     # create gating window
-    window_width = abs(stop_idx - start_idx)
-    window = signal.get_window(window, window_width)
+    window_width = abs(stop_idx - start_idx) + 1
+    window = get_window(window, window_width)
 
     # create the gate by padding the window with zeros
     gate = npy.zeros_like(t)
-    gate[start_idx:stop_idx] = window
+    gate[start_idx:stop_idx+1] = window
 
     if method == 'convolution':
         # frequency-domain gating
