@@ -53,7 +53,7 @@ General Purpose Objects
 import contextlib
 import fnmatch
 import os
-from typing import Iterable, Tuple, List, Union, Any, TypeVar
+from typing import Iterable, Tuple, List, Union, Any, TypeVar, Callable
 import warnings
 import numpy as npy
 from datetime import datetime
@@ -63,7 +63,7 @@ import re
 from subprocess import Popen, PIPE
 import sys
 from functools import wraps
-from .constants import Number, NumberLike
+from .constants import Number
 
 try:
     from matplotlib.figure import Figure
@@ -74,9 +74,18 @@ except ImportError:
     Axes = TypeVar("Axes")
     pass
 
+def plotting_available() -> bool:
+    return "matplotlib" in sys.modules
+
+def partial_with_docs(func, *args1, **kwargs1):
+    @wraps(func)
+    def method(self, *args2, **kwargs2):
+        return func(self, *args1, *args2, **kwargs1, **kwargs2)
+    return method
+
 def axes_kwarg(func):
     """
-    This decorator checks if a :class:`matplotlib.axes.Axes` object is passed, 
+    This decorator checks if a :class:`matplotlib.axes.Axes` object is passed,
     if not the current axis will be gathered through :func:`plt.gca`.
 
     Raises
@@ -97,6 +106,13 @@ def axes_kwarg(func):
 
     return wrapper
 
+def copy_doc(copy_func: Callable) -> Callable:
+    """Use Example: copy_doc(self.copy_func)(self.func) or used as deco"""
+    def wrapper(func: Callable) -> Callable:
+        func.__doc__ = copy_func.__doc__
+        return func
+    return wrapper
+
 
 def subplots(*args, **kwargs) -> Tuple[Figure, npy.ndarray]:
     """
@@ -711,7 +727,7 @@ def unique_name(name: str, names: list, exclude: int = -1) -> str:
 
         for num in range(suffix, 100, 1):
             name = f"{name_base:s}_{num:02d}"
-            if has_duplicate_value(name, names, exclude) is False:
+            if not has_duplicate_value(name, names, exclude):
                 break
     return name
 
@@ -862,8 +878,7 @@ def suppress_warning_decorator(msg):
     def suppress_warnings_decorated(func):
         @wraps(func)
         def suppressed_func(*k, **kw):
-            show_warnings = []
-            with warnings.catch_warnings() as wlist:
+            with warnings.catch_warnings():
                 warnings.filterwarnings("ignore", message=f"{msg}.*")
                 res = func(*k, **kw)
             return res
