@@ -2,7 +2,7 @@ import os
 import sys
 import traceback
 
-from qtpy import QtWidgets, QtCore, QtGui
+from qtpy import QtWidgets, QtCore
 
 import skrf
 from . import numeric_inputs
@@ -668,7 +668,7 @@ class MeasurementDialog(QtWidgets.QDialog):
         self.spinBox_timeout.setMaximum(600000)
         try:
             self.spinBox_timeout.setValue(nwa.resource.timeout)
-        except:
+        except Exception:
             self.spinBox_timeout.setValue(3000)
         self.spinBox_timeout.setSingleStep(1000)
         self.horizontalLayout_timeout = QtWidgets.QHBoxLayout()
@@ -780,4 +780,4 @@ class MeasurementDialog(QtWidgets.QDialog):
             item = QtWidgets.QListWidgetItem()
             item.setText(trace["label"])
             item.trace = trace
-            self.listWidget_traces.addItem(item)
\ No newline at end of file
+            self.listWidget_traces.addItem(item)
